# "on_off foo" wil turn into "ON" or "OFF"
%define on_off() %{expand:%%{?with_%{1}:ON}%%{!?with_%{1}:OFF}}

%define _with_tests on
%define _with_livedumper on
%define _with_crashservice on
%bcond_with doc
%bcond_with tests
%bcond_with livedumper
%bcond_with crashservice

# NOTE: To disable coredump set DumpCore=0 in configuration file

Name:           crash-worker
Summary:        Coredump handler and report generator for Tizen
Version:        5.5.41
Release:        1
Group:          Framework/system
License:        Apache-2.0 and BSD-2-Clause and MIT
Source0:        %{name}-%{version}.tar.gz
Source1001:     crash-worker.manifest
BuildRequires:  pkgconfig(dlog)
BuildRequires:  pkgconfig(libtzplatform-config)
BuildRequires:  pkgconfig(iniparser)
BuildRequires:  pkgconfig(capi-system-info)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  cmake
BuildRequires:  pkgconfig(pkgmgr-info)
BuildRequires:  pkgconfig(libunwind-generic)
BuildRequires:  libelf-devel libelf
BuildRequires:  libdw-devel libdw
BuildRequires:  libcap-devel

%if %{with doc}
BuildRequires:  doxygen
%endif

%if %{with livedumper}
BuildRequires:  boost-devel
%endif

Requires(post): coreutils
Requires(post): tar
Requires(post): gzip
Requires:       zip
Requires:       libelf
Requires:       libdw
Requires:       minicoredumper >= 2.1.0
Requires:       %{_bindir}/buxton2ctl
%if %{with crashservice}
Requires:       %{name}-livedumper = %{version}-%{release}
%endif
%description

%package -n     libcrash-service
Summary:        libcrash-service provides API to communicate with crash-service
%description -n libcrash-service

%package        devel
Requires:       libcrash-service
Summary:        Crash-manager headers and library for linking
%description    devel

%if %{with doc}
%package        doc
Summary:        Documentation package for crash-worker
Group:          Framework/System
%description    doc
%endif

%if %{with tests}
%package        tests
Summary:        Package with binaries and data for crash-worker tests
%description    tests
%endif

%if %{with livedumper}
%package        livedumper
Summary:        Livedumper allows to dump core of live process
%description    livedumper
%endif

%package        system-tests
Summary:        System tests for crash-worker components
Requires:       diff
Requires:       gdb
Requires:       coreutils
Requires:       tlm
Requires:       /bin/bash
Requires:       /usr/bin/unzip
Requires:       /usr/bin/mcookie
Requires:       %{_sbindir}/minicoredumper
Requires:       %{name}-system-tests-debuginfo = %{version}-%{release}
%description    system-tests

%prep
%setup -q

#Path to store logs and coredump files
%define crash_root_path %{TZ_SYS_CRASH_ROOT}
%define crash_path      %{TZ_SYS_CRASH}
%define crash_temp      %{crash_root_path}/temp

#Debug mode path - existence of file at path below mean that core file should be generated
%define debugmode_path      %{TZ_SYS_ETC}/.debugmode

%define upgrade_script_path %{TZ_SYS_RO_SHARE}/upgrade/scripts

%build
cp %{SOURCE1001} .

export CFLAGS+=" -Werror"

%ifarch %{arm} aarch64
	%define ARCH arm
%else
	%define ARCH x86
%endif

%ifarch %{arm} %ix86
	%define ARCH_BIT 32
%else
	%define ARCH_BIT 64
%endif

%cmake . \
	   -DCMAKE_INSTALL_PREFIX=%{_prefix} \
	   -DTMP_FILES_DIR=%{_sysconfdir}/tmpfiles.d \
	   -DARCH=%{ARCH} \
	   -DARCH_BIT=%{ARCH_BIT} \
	   -DDUMP_SYSTEMSTATE_CONFIG_DIR_PATH=%{_sysconfdir}/dump_systemstate.conf.d \
	   -DCRASH_MANAGER_CONFIG_PATH=%{_sysconfdir}/crash-manager.conf \
	   -DCRASH_ROOT_PATH=%{crash_root_path} \
	   -DCRASH_PATH=%{crash_path} \
	   -DCRASH_TEMP=%{crash_temp} \
	   -DDEBUGMODE_PATH=%{debugmode_path} \
	   -DMINICOREDUMPER_BIN_PATH=%{_sbindir}/minicoredumper \
	   -DMINICOREDUMPER_CONFIG_PATH=%{_sysconfdir}/minicoredumper/minicoredumper.cfg.json \
	   -DLIVEDUMPER_BIN_PATH=%{_bindir}/livedumper \
	   -DDUMP_SYSTEMSTATE_BIN_PATH=%{_bindir}/dump_systemstate \
	   -DCRASH_STACK_BIN_PATH=%{_libexecdir}/crash-stack \
	   -DCRASH_POPUP_BIN_PATH=%{_libexecdir}/crash-popup-launch \
	   -DCRASH_NOTIFY_BIN_PATH=%{_libexecdir}/crash-notify-send \
	   -DCRASH_TESTS_PATH=%{_libdir}/crash-worker/tests \
	   -DCRASH_SYSTEM_TESTS_PATH=%{_libdir}/crash-worker/system-tests \
	   -DLIVEDUMPER=%{on_off livedumper} \
	   -DCRASH_SERVICE=%{on_off crashservice} \
	   -DUPGRADE_SCRIPT_PATH=%{upgrade_script_path} \
	   -DLOGGER=dlog \
	   -DDLOG_LOG_LEVEL=DLOG_INFO \
	   -DVERSION=%{version}

make %{?jobs:-j%jobs}

%if %{with doc}
make doc
%endif

%install
rm -rf %{buildroot}
%make_install
mkdir -p %{buildroot}%{crash_root_path}
mkdir -p %{buildroot}%{crash_path}
mkdir -p %{buildroot}%{crash_temp}

%post
/usr/bin/chsmack -a "System" -t %{crash_path}
/usr/bin/chsmack -a "System" -t %{crash_temp}

%files
%license LICENSE LICENSE.BSD LICENSE.MIT
%manifest crash-worker.manifest
%defattr(-,crash_worker,crash_worker,-)
%dir %{crash_root_path}
%dir %{crash_path}
%dir %{crash_temp}
%{_sysconfdir}/crash-manager.conf
%{_sysconfdir}/crash-manager.conf.d/crash-manager.conf.example
%attr(-,root,root) %{_prefix}/lib/sysctl.d/70-crash-manager.conf
%attr(0750,crash_worker,crash_worker) %{_bindir}/crash-manager
%attr(0750,crash_worker,crash_worker) %{_bindir}/dump_systemstate
%{_sysconfdir}/dump_systemstate.conf.d/files/*.conf*
%{_sysconfdir}/dump_systemstate.conf.d/programs/*.conf*
%{_libexecdir}/crash-stack
%{_libexecdir}/crash-popup-launch
%{_libexecdir}/crash-notify-send
%{_libdir}/libcrash-manager.so.*

%if %{with crashservice}
%attr(0750,crash_worker,crash_worker) %{_bindir}/crash-service
%attr(-,root,root) %{_unitdir}/crash-service.service
%attr(-,root,root) %{_sysconfdir}/dbus-1/system.d/crash-service.conf
%attr(-,root,root) %{_datadir}/dbus-1/system-services/org.tizen.system.crash.livedump.service
%endif

#upgrade script
%attr(-,root,root) %{upgrade_script_path}/500.crash-manager-upgrade.sh

%files -n libcrash-service
%{_libdir}/libcrash-service.so.*

%files devel
%{_includedir}/crash-manager.h
%{_libdir}/libcrash-manager.so
%{_libdir}/pkgconfig/crash-manager.pc
%if %{with crashservice}
%{_includedir}/libcrash-service.h
%{_libdir}/libcrash-service.so
%{_libdir}/pkgconfig/crash-service.pc
%endif

%if %{with doc}
%files doc
%{_datadir}/doc/crash-worker
%endif

%if %{with tests}
%files tests
%manifest %{name}.manifest
%defattr(-,root,root)
%{_libdir}/crash-worker/tests/test1-default-crash
%{_libdir}/crash-worker/tests/test1-default-sleep
%{_libdir}/crash-worker/tests/test1-default-ill
%{_libdir}/crash-worker/tests/test1-custom-crash
%{_libdir}/crash-worker/tests/test1-custom-sleep
%{_libdir}/crash-worker/tests/test1-custom-ill
%{_libdir}/crash-worker/tests/run_tests.sh
%{_libdir}/crash-worker/tests/tests_common.sh
%{_libdir}/crash-worker/tests/crash_common.sh

%endif

%if %{with livedumper}
%files livedumper
%manifest %{name}.manifest
%{_bindir}/livedumper
%endif

%files system-tests
%manifest %{name}.manifest
%{_bindir}/crash-worker-system-tests-run

%{_libdir}/crash-worker/system-tests/check_minicore_mem/check_minicore_mem.sh
%{_libdir}/crash-worker/system-tests/check_minicore_mem/cp.sh
%{_libdir}/crash-worker/system-tests/clean_temp/clean_temp.sh
%{_libdir}/crash-worker/system-tests/cmp_backtraces/cmp_backtraces.sh
%{_libdir}/crash-worker/system-tests/cmp_backtraces/cp.sh
%{_libdir}/crash-worker/system-tests/copy_tizen_manifest/copy_tizen_manifest.sh
%{_libdir}/crash-worker/system-tests/crash_root_path/crash_root_path.sh
%{_libdir}/crash-worker/system-tests/critical_process/critical_process.sh
%{_libdir}/crash-worker/system-tests/dbus_notify/dbus_notify.sh
%{_libdir}/crash-worker/system-tests/dbus_notify_legacy/dbus_notify_legacy.sh
%{_libdir}/crash-worker/system-tests/dump_systemstate_extras/dump_systemstate_extras.sh
%{_libdir}/crash-worker/system-tests/exclude_paths/exclude_paths.sh
%{_libdir}/crash-worker/system-tests/extra_script/extra_script.sh
%{_libdir}/crash-worker/system-tests/full_core/full_core.sh
%{_libdir}/crash-worker/system-tests/info_file/info_file.sh
%{_libdir}/crash-worker/system-tests/libcrash-service/libcrash-service.sh
%{_libdir}/crash-worker/system-tests/log_file/log_file.sh
%{_libdir}/crash-worker/system-tests/output_param/output_param.sh
%{_libdir}/crash-worker/system-tests/report_basic/report_basic.sh
%{_libdir}/crash-worker/system-tests/report_type_info/report_type_info.sh
%{_libdir}/crash-worker/system-tests/so_info_file/so_info_file.sh
%{_libdir}/crash-worker/system-tests/temp_lock/temp_lock.sh
%{_libdir}/crash-worker/system-tests/time_test/cp.sh
%{_libdir}/crash-worker/system-tests/time_test/time_test.sh
%{_libdir}/crash-worker/system-tests/utils/btee
%{_libdir}/crash-worker/system-tests/utils/kenny
%{_libdir}/crash-worker/system-tests/utils/libcrash-servicetest
%{_libdir}/crash-worker/system-tests/utils/minicore-utils.sh
%{_libdir}/crash-worker/system-tests/wait_for_opt_usr/wait_for_opt_usr.sh
%{_libdir}/crash-worker/system-tests/without_so_info_file/without_so_info_file.sh
%{_libdir}/crash-worker/system-tests/without_core/without_core.sh

%if %{with livedumper}
%{_libdir}/crash-worker/system-tests/livedumper/livedumper.sh
%endif
